@@ -171,6 +171,23 @@ get_result_iterator (void *cls,
            (char *) data);
   if (record_route && verbose)
   {
+    {
+      struct GNUNET_PeerIdentity my_identity;
+
+      GNUNET_break (GNUNET_OK ==
+                    GNUNET_CRYPTO_get_peer_identity (cfg,
+                                                     &my_identity));
+      GNUNET_break (0 ==
+                    GNUNET_DHT_verify_path (data,
+                                            size,
+                                            exp,
+                                            trunc_peer,
+                                            put_path,
+                                            put_path_length,
+                                            get_path,
+                                            get_path_length,
+                                            &my_identity));
+    }
     fprintf (stdout,
              "  GET path: ");
     for (unsigned int i = 0; i < get_path_length; i++)
@@ -187,7 +204,7 @@ get_result_iterator (void *cls,
                GNUNET_i2s (&put_path[i].pred));
     if (NULL != trunc_peer)
       fprintf (stdout,
-               "T%s",
+               "!%s",
                GNUNET_i2s (trunc_peer));
     fprintf (stdout,
              "\n");
@@ -267,6 +284,7 @@ run (void *cls,
 int
 main (int argc, char *const *argv)
 {
+  char *u8_argv = NULL;
   struct GNUNET_GETOPT_CommandLineOption options[] = {
     GNUNET_GETOPT_option_string (
       'k',
@@ -324,6 +342,9 @@ main (int argc, char *const *argv)
             NULL))
          ? ret
          : 1;
+  // This is ugly, but meh. The GNUNET_STRINGS_get_utf8_args allows us to do this.
+  u8_argv = (char*) argv;
+  GNUNET_free (u8_argv);
 }
 
 
