@@ -662,11 +662,12 @@ send_find_peer_message (void *cls)
     struct GNUNET_CONTAINER_BloomFilter *peer_bf;
 
     bg = GNUNET_BLOCK_group_create (GDS_block_context,
-                                    GNUNET_BLOCK_TYPE_DHT_URL_HELLO,
+                                    GNUNET_BLOCK_TYPE_DHT_HELLO,
                                     NULL,
                                     0,
-                                    "filter-size",
-                                    DHT_BLOOM_SIZE,
+                                    "set-seen-size",
+                                    GNUNET_CONTAINER_multipeermap_size (
+                                      all_connected_peers),
                                     NULL);
     GNUNET_CONTAINER_multipeermap_iterate (all_connected_peers,
                                            &add_known_to_bloom,
@@ -676,7 +677,7 @@ send_find_peer_message (void *cls)
                                            DHT_BLOOM_SIZE,
                                            GNUNET_CONSTANTS_BLOOMFILTER_K);
     if (GNUNET_OK !=
-        GDS_NEIGHBOURS_handle_get (GNUNET_BLOCK_TYPE_DHT_URL_HELLO,
+        GDS_NEIGHBOURS_handle_get (GNUNET_BLOCK_TYPE_DHT_HELLO,
                                    GNUNET_DHT_RO_FIND_APPROXIMATE
                                    | GNUNET_DHT_RO_RECORD_ROUTE,
                                    FIND_PEER_REPLICATION_LEVEL,
@@ -1303,7 +1304,7 @@ hello_check (const struct GNUNET_DATACACHE_Block *bd)
   struct GNUNET_PeerIdentity pid;
   struct GNUNET_HELLO_Builder *b;
 
-  if (GNUNET_BLOCK_TYPE_DHT_URL_HELLO != bd->type)
+  if (GNUNET_BLOCK_TYPE_DHT_HELLO != bd->type)
     return;
 
   b = GNUNET_HELLO_builder_from_block (bd->data,
@@ -1996,14 +1997,45 @@ handle_dht_p2p_put (void *cls,
                               GNUNET_NO);
     return;
   }
-  if (GNUNET_NO ==
-      GNUNET_BLOCK_check_block (GDS_block_context,
-                                bd.type,
-                                bd.data,
-                                bd.data_size))
   {
-    GNUNET_break_op (0);
-    return;
+    /* Only call 'check_block' if that keeps our CPU load (from
+       the cryptography) below 50% on average */
+    static struct GNUNET_TIME_Relative avg_latency;
+    static struct GNUNET_TIME_Absolute next_time;
+
+    if (GNUNET_TIME_absolute_is_past (next_time))
+    {
+      struct GNUNET_TIME_Absolute now
+        = GNUNET_TIME_absolute_get ();
+      struct GNUNET_TIME_Relative latency;
+      struct GNUNET_TIME_Relative delta;
+
+      if (GNUNET_NO ==
+          GNUNET_BLOCK_check_block (GDS_block_context,
+                                    bd.type,
+                                    bd.data,
+                                    bd.data_size))
+      {
+        GNUNET_break_op (0);
+        return;
+      }
+      latency = GNUNET_TIME_absolute_get_duration (now);
+      /* Use *moving average* to estimate check_block latency */
+      avg_latency
+        = GNUNET_TIME_relative_divide (
+            GNUNET_TIME_relative_add (
+              GNUNET_TIME_relative_multiply (avg_latency,
+                                             7),
+              latency),
+            8);
+      /* average delay = 50% of avg_latency => 50% CPU load from crypto (at most) */
+      delta.rel_value_us
+        = GNUNET_CRYPTO_random_u64 (GNUNET_CRYPTO_QUALITY_WEAK,
+                                    avg_latency.rel_value_us > 0
+                                        ? avg_latency.rel_value_us
+                                        : 1LLU);
+      next_time = GNUNET_TIME_relative_to_absolute (delta);
+    }
   }
   if (! has_path)
     putlen = 0;
@@ -2168,7 +2200,7 @@ handle_find_my_hello (struct PeerInfo *pi,
     }
     else if (GNUNET_BLOCK_REPLY_OK_MORE ==
              GNUNET_BLOCK_check_reply (GDS_block_context,
-                                       GNUNET_BLOCK_TYPE_DHT_URL_HELLO,
+                                       GNUNET_BLOCK_TYPE_DHT_HELLO,
                                        bg,
                                        &GDS_my_identity_hash,
                                        NULL, 0,
@@ -2176,7 +2208,7 @@ handle_find_my_hello (struct PeerInfo *pi,
                                        block_size))
     {
       struct GNUNET_DATACACHE_Block bd = {
-        .type = GNUNET_BLOCK_TYPE_DHT_URL_HELLO,
+        .type = GNUNET_BLOCK_TYPE_DHT_HELLO,
         .expiration_time
           = GNUNET_TIME_relative_to_absolute (
               GNUNET_HELLO_ADDRESS_EXPIRATION),
@@ -2225,7 +2257,7 @@ handle_find_local_hello (struct PeerInfo *pi,
        (GNUNET_BLOCK_REPLY_OK_MORE ==
         GNUNET_BLOCK_check_reply (
           GDS_block_context,
-          GNUNET_BLOCK_TYPE_DHT_URL_HELLO,
+          GNUNET_BLOCK_TYPE_DHT_HELLO,
           bg,
           &peer->phash,
           NULL, 0,        /* xquery */
@@ -2233,7 +2265,7 @@ handle_find_local_hello (struct PeerInfo *pi,
           peer->hello_size)) )
   {
     struct GNUNET_DATACACHE_Block bd = {
-      .type = GNUNET_BLOCK_TYPE_DHT_URL_HELLO,
+      .type = GNUNET_BLOCK_TYPE_DHT_HELLO,
       .expiration_time = peer->hello_expiration,
       .key = peer->phash,
       .data = peer->hello,
@@ -2362,7 +2394,7 @@ handle_dht_p2p_get (void *cls,
          (GDS_am_closest_peer (&get->key,
                                peer_bf)) )
     {
-      if ( (GNUNET_BLOCK_TYPE_DHT_URL_HELLO == type) ||
+      if ( (GNUNET_BLOCK_TYPE_DHT_HELLO == type) ||
            (GNUNET_BLOCK_TYPE_ANY == type) )
       {
         GNUNET_STATISTICS_update (GDS_stats,
@@ -2377,7 +2409,7 @@ handle_dht_p2p_get (void *cls,
                                    &get->key,
                                    bg);
       }
-      if (GNUNET_BLOCK_TYPE_DHT_URL_HELLO != type)
+      if (GNUNET_BLOCK_TYPE_DHT_HELLO != type)
       {
         if (0 != (options & GNUNET_DHT_RO_FIND_APPROXIMATE))
           eval = GDS_DATACACHE_get_closest (&get->key,
@@ -2872,8 +2904,6 @@ GDS_try_connect (void *cls,
   GNUNET_assert ( (peer_bucket >= 0) &&
                   ((unsigned int) peer_bucket < MAX_BUCKETS));
   bucket = &k_buckets[peer_bucket];
-  if (bucket->peers_size >= bucket_size)
-    return; /* do not care */
   for (struct PeerInfo *pi = bucket->head;
        NULL != pi;
        pi = pi->next)
@@ -2882,10 +2912,12 @@ GDS_try_connect (void *cls,
                        pid))
     {
       /* already connected */
-      /* TODO: maybe consider 'uri' anyway as an additional
-         alternative address??? */
+      GDS_u_try_connect (pid,
+                         uri);
       return;
     }
+  if (bucket->peers_size >= bucket_size)
+    return; /* do not care */
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Discovered peer %s at %s suitable for bucket %d (%u/%u), trying to connect\n",
               GNUNET_i2s (pid),
