@@ -24,9 +24,7 @@
  */
 #include "platform.h"
 #include <gnunet_util_lib.h>
-#include <gnunet_dnsparser_lib.h>
 #include <gnunet_gns_service.h>
-#include <gnunet_dnsstub_lib.h>
 #include "gnunet_vpn_service.h"
 #include "gns.h"
 
