@@ -37,7 +37,6 @@
 #endif
 #endif
 #include <gnunet_util_lib.h>
-#include <gnunet_dnsparser_lib.h>
 #include <gnunet_gnsrecord_lib.h>
 #include <gnunet_namestore_service.h>
 #include <gnunet_gns_service.h>
@@ -205,7 +204,11 @@ process_lookup_result (void *cls,
     if (raw)
       printf ("%s\n", string_val);
     else
-      printf ("Got `%s' record: %s\n", typename, string_val);
+      printf ("Got `%s' record: %s%s\n",
+              typename,
+              string_val,
+              (0 != (rd[i].flags & GNUNET_GNSRECORD_RF_SUPPLEMENTAL)) ?
+              " (supplemental)" : "");
     GNUNET_free (string_val);
   }
   GNUNET_SCHEDULER_shutdown ();
@@ -275,7 +278,7 @@ run (void *cls,
   {
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                 _ ("Cannot resolve using GNS: GNUnet peer not running\n"));
-    global_ret = 2;
+    global_ret = 5;
     return;
   }
   to_task = GNUNET_SCHEDULER_add_delayed (timeout,
@@ -372,7 +375,7 @@ main (int argc, char *const *argv)
                             options,
                             &run,
                             NULL);
-  GNUNET_free ((void *) argv);
+  GNUNET_free_nz ((void *) argv);
   if (GNUNET_OK != ret)
     return 1;
   return global_ret;
