@@ -23,12 +23,14 @@
  * @brief GNUnet MESSENGER service
  */
 
+#include "platform.h"
 #include "gnunet-service-messenger_member.h"
 
 #include "gnunet-service-messenger_member_session.h"
 
 struct GNUNET_MESSENGER_Member*
-create_member (struct GNUNET_MESSENGER_MemberStore *store, const struct GNUNET_ShortHashCode *id)
+create_member (struct GNUNET_MESSENGER_MemberStore *store,
+               const struct GNUNET_ShortHashCode *id)
 {
   GNUNET_assert (store);
 
@@ -50,7 +52,9 @@ create_member (struct GNUNET_MESSENGER_MemberStore *store, const struct GNUNET_S
 }
 
 static int
-iterate_destroy_session (void *cls, const struct GNUNET_HashCode *key, void *value)
+iterate_destroy_session (void *cls,
+                         const struct GNUNET_HashCode *key,
+                         void *value)
 {
   struct GNUNET_MESSENGER_MemberSession *session = value;
   destroy_member_session(session);
@@ -77,7 +81,8 @@ get_member_id (const struct GNUNET_MESSENGER_Member *member)
 }
 
 static int
-callback_scan_for_sessions (void *cls, const char *filename)
+callback_scan_for_sessions (void *cls,
+                            const char *filename)
 {
   struct GNUNET_MESSENGER_Member *member = cls;
 
@@ -95,7 +100,8 @@ callback_scan_for_sessions (void *cls, const char *filename)
 }
 
 void
-load_member (struct GNUNET_MESSENGER_MemberStore *store, const char *directory)
+load_member (struct GNUNET_MESSENGER_MemberStore *store,
+             const char *directory)
 {
   GNUNET_assert ((store) && (directory));
 
@@ -107,6 +113,8 @@ load_member (struct GNUNET_MESSENGER_MemberStore *store, const char *directory)
   if (GNUNET_YES != GNUNET_DISK_file_test (config_file))
     goto free_config;
 
+  GNUNET_log(GNUNET_ERROR_TYPE_DEBUG, "Load member configuration: %s\n", config_file);
+
   struct GNUNET_CONFIGURATION_Handle *cfg = GNUNET_CONFIGURATION_create ();
 
   if (GNUNET_OK == GNUNET_CONFIGURATION_parse (cfg, config_file))
@@ -139,7 +147,9 @@ free_config:
 }
 
 static int
-iterate_load_next_session (void *cls, const struct GNUNET_HashCode *key, void *value)
+iterate_load_next_session (void *cls,
+                           const struct GNUNET_HashCode *key,
+                           void *value)
 {
   const char* sessions_directory = cls;
 
@@ -156,7 +166,8 @@ iterate_load_next_session (void *cls, const struct GNUNET_HashCode *key, void *v
 }
 
 void
-load_member_next_sessions (const struct GNUNET_MESSENGER_Member *member, const char *directory)
+load_member_next_sessions (const struct GNUNET_MESSENGER_Member *member,
+                           const char *directory)
 {
   GNUNET_assert ((member) && (directory));
 
@@ -169,7 +180,9 @@ load_member_next_sessions (const struct GNUNET_MESSENGER_Member *member, const c
 }
 
 static int
-iterate_save_session (void *cls, const struct GNUNET_HashCode *key, void *value)
+iterate_save_session (void *cls,
+                      const struct GNUNET_HashCode *key,
+                      void *value)
 {
   const char* sessions_directory = cls;
 
@@ -187,13 +200,16 @@ iterate_save_session (void *cls, const struct GNUNET_HashCode *key, void *value)
 }
 
 void
-save_member (struct GNUNET_MESSENGER_Member *member, const char *directory)
+save_member (struct GNUNET_MESSENGER_Member *member,
+             const char *directory)
 {
   GNUNET_assert ((member) && (directory));
 
   char *config_file;
   GNUNET_asprintf (&config_file, "%s%s", directory, "member.cfg");
 
+  GNUNET_log(GNUNET_ERROR_TYPE_DEBUG, "Save member configuration: %s\n", config_file);
+
   struct GNUNET_CONFIGURATION_Handle *cfg = GNUNET_CONFIGURATION_create ();
 
   char *id_data = GNUNET_STRINGS_data_to_string_alloc (&(member->id), sizeof(member->id));
@@ -221,7 +237,8 @@ save_member (struct GNUNET_MESSENGER_Member *member, const char *directory)
 }
 
 static void
-sync_session_contact_from_next (struct GNUNET_MESSENGER_MemberSession *session, struct GNUNET_MESSENGER_MemberSession *next)
+sync_session_contact_from_next (struct GNUNET_MESSENGER_MemberSession *session,
+                                struct GNUNET_MESSENGER_MemberSession *next)
 {
   GNUNET_assert((session) && (next));
 
@@ -235,7 +252,9 @@ sync_session_contact_from_next (struct GNUNET_MESSENGER_MemberSession *session,
 }
 
 static int
-iterate_sync_session_contact (void *cls, const struct GNUNET_HashCode *key, void *value)
+iterate_sync_session_contact (void *cls,
+                              const struct GNUNET_HashCode *key,
+                              void *value)
 {
   struct GNUNET_MESSENGER_MemberSession *session = value;
 
@@ -254,7 +273,8 @@ sync_member_contacts (struct GNUNET_MESSENGER_Member *member)
 }
 
 struct GNUNET_MESSENGER_MemberSession*
-get_member_session (const struct GNUNET_MESSENGER_Member *member, const struct GNUNET_IDENTITY_PublicKey *public_key)
+get_member_session (const struct GNUNET_MESSENGER_Member *member,
+                    const struct GNUNET_IDENTITY_PublicKey *public_key)
 {
   GNUNET_assert ((member) && (public_key));
 
@@ -272,7 +292,9 @@ struct GNUNET_MESSENGER_ClosureSearchSession {
 };
 
 static int
-iterate_search_session (void *cls, const struct GNUNET_HashCode *key, void *value)
+iterate_search_session (void *cls,
+                        const struct GNUNET_HashCode *key,
+                        void *value)
 {
   struct GNUNET_MESSENGER_ClosureSearchSession* search = cls;
   struct GNUNET_MESSENGER_MemberSession *session = value;
@@ -285,7 +307,8 @@ iterate_search_session (void *cls, const struct GNUNET_HashCode *key, void *valu
 }
 
 static struct GNUNET_MESSENGER_MemberSession*
-try_member_session (struct GNUNET_MESSENGER_Member *member, const struct GNUNET_IDENTITY_PublicKey *public_key)
+try_member_session (struct GNUNET_MESSENGER_Member *member,
+                    const struct GNUNET_IDENTITY_PublicKey *public_key)
 {
   struct GNUNET_MESSENGER_MemberSession* session = get_member_session(member, public_key);
 
@@ -301,7 +324,8 @@ try_member_session (struct GNUNET_MESSENGER_Member *member, const struct GNUNET_
 }
 
 struct GNUNET_MESSENGER_MemberSession*
-get_member_session_of (struct GNUNET_MESSENGER_Member *member, const struct GNUNET_MESSENGER_Message *message,
+get_member_session_of (struct GNUNET_MESSENGER_Member *member,
+                       const struct GNUNET_MESSENGER_Message *message,
                        const struct GNUNET_HashCode *hash)
 {
   GNUNET_assert ((member) && (message) && (hash) &&
@@ -324,7 +348,8 @@ get_member_session_of (struct GNUNET_MESSENGER_Member *member, const struct GNUN
 }
 
 void
-add_member_session (struct GNUNET_MESSENGER_Member *member, struct GNUNET_MESSENGER_MemberSession *session)
+add_member_session (struct GNUNET_MESSENGER_Member *member,
+                    struct GNUNET_MESSENGER_MemberSession *session)
 {
   if (!session)
     return;
@@ -344,7 +369,8 @@ add_member_session (struct GNUNET_MESSENGER_Member *member, struct GNUNET_MESSEN
 }
 
 void
-remove_member_session (struct GNUNET_MESSENGER_Member *member, struct GNUNET_MESSENGER_MemberSession *session)
+remove_member_session (struct GNUNET_MESSENGER_Member *member,
+                       struct GNUNET_MESSENGER_MemberSession *session)
 {
   GNUNET_assert ((member) && (session) && (session->member == member));
 
@@ -364,7 +390,9 @@ struct GNUNET_MESSENGER_ClosureIterateSessions {
 };
 
 static int
-iterate_member_sessions_it (void *cls, const struct GNUNET_HashCode *key, void *value)
+iterate_member_sessions_it (void *cls,
+                            const struct GNUNET_HashCode *key,
+                            void *value)
 {
   struct GNUNET_MESSENGER_ClosureIterateSessions *iterate = cls;
   struct GNUNET_MESSENGER_MemberSession *session = value;
@@ -373,7 +401,9 @@ iterate_member_sessions_it (void *cls, const struct GNUNET_HashCode *key, void *
 }
 
 int
-iterate_member_sessions (struct GNUNET_MESSENGER_Member *member, GNUNET_MESSENGER_MemberIteratorCallback it, void *cls)
+iterate_member_sessions (struct GNUNET_MESSENGER_Member *member,
+                         GNUNET_MESSENGER_MemberIteratorCallback it,
+                         void *cls)
 {
   GNUNET_assert ((member) && (member->sessions) && (it));
 
