@@ -26,6 +26,8 @@
 #include "platform.h"
 #include "gnunet_util_lib.h"
 #include "gnunet_testing_ng_lib.h"
+#include "gnunet_testing_plugin.h"
+#include "gnunet_testing_barrier.h"
 #include "gnunet_testing_netjail_lib.h"
 
 #define NETJAIL_START_SCRIPT "netjail_start.sh"
@@ -222,15 +224,8 @@ GNUNET_TESTING_cmd_netjail_start (const char *label,
   ns = GNUNET_new (struct NetJailState);
   ns->topology_config = topology_config;
   ns->read_file = read_file;
-  {
-    struct GNUNET_TESTING_Command cmd = {
-      .cls = ns,
-      .label = label,
-      .run = &netjail_start_run,
-      .ac = &ns->ac,
-      .cleanup = &netjail_start_cleanup
-    };
-
-    return cmd;
-  }
+  return GNUNET_TESTING_command_new (ns, label,
+                                     &netjail_start_run,
+                                     &netjail_start_cleanup,
+                                     NULL, &ns->ac);
 }
