@@ -217,7 +217,6 @@ static void
 netjail_exec_cleanup (void *cls)
 {
   struct NetJailState *ns = cls;
-  TST_interpreter_delete_barriers (ns->is);
   GNUNET_free (ns);
 }
 
@@ -489,6 +488,7 @@ helper_mst (void *cls, const struct GNUNET_MessageHeader *message)
     } else if (ns->number_of_local_tests_finished == total_number)
     {
       GNUNET_SCHEDULER_cancel (ns->timeout_task);
+      ns->timeout_task = NULL;
       GNUNET_TESTING_async_finish (&ns->ac);
     }
     break;
@@ -525,7 +525,8 @@ exp_cb (void *cls)
   struct NetJailState *ns = cls;
 
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Called exp_cb.\n");
-  GNUNET_SCHEDULER_cancel (ns->timeout_task);
+  if (NULL != ns->timeout_task)
+    GNUNET_SCHEDULER_cancel (ns->timeout_task);
   GNUNET_TESTING_async_fail (&(ns->ac));
 }
 
@@ -612,7 +613,8 @@ start_helper (struct NetJailState *ns,
   GNUNET_asprintf (&local_m_char, "%u", ns->local_m);
   GNUNET_asprintf (&global_n_char, "%u",ns->global_n);
   GNUNET_asprintf (&known_char, "%u",ns->known);
-  GNUNET_asprintf (&node_id, "%06x-%08x\n",
+  GNUNET_asprintf (&node_id, "%s%06x-%06x\n",
+                   "if",
                    pid,
                    script_num);
   // GNUNET_asprintf (&topology_data, "'%s'", ns->topology_data);
