@@ -26,6 +26,8 @@
 #include "platform.h"
 #include "gnunet_util_lib.h"
 #include "gnunet_testing_ng_lib.h"
+#include "gnunet_testing_plugin.h"
+#include "gnunet_testing_barrier.h"
 #include "gnunet_testing_netjail_lib.h"
 #include "testing_cmds.h"
 
@@ -40,13 +42,13 @@ struct SendPeerReadyState
    * Callback to write messages to the master loop.
    *
    */
-  TESTING_CMD_HELPER_write_cb write_message;
+  GNUNET_TESTING_cmd_helper_write_cb write_message;
 
   /**
    * The message send back to the master loop.
    *
    */
-  struct GNUNET_CMDS_PEER_STARTED *reply;
+  struct GNUNET_TESTING_CommandPeerStarted *reply;
 };
 
 
@@ -86,11 +88,11 @@ send_peer_ready_run (void *cls,
                      struct GNUNET_TESTING_Interpreter *is)
 {
   struct SendPeerReadyState *sprs = cls;
-  struct GNUNET_CMDS_PEER_STARTED *reply;
+  struct GNUNET_TESTING_CommandPeerStarted *reply;
   size_t msg_length;
 
-  msg_length = sizeof(struct GNUNET_CMDS_PEER_STARTED);
-  reply = GNUNET_new (struct GNUNET_CMDS_PEER_STARTED);
+  msg_length = sizeof(struct GNUNET_TESTING_CommandPeerStarted);
+  reply = GNUNET_new (struct GNUNET_TESTING_CommandPeerStarted);
   reply->header.type = htons (GNUNET_MESSAGE_TYPE_CMDS_HELPER_PEER_STARTED);
   reply->header.size = htons ((uint16_t) msg_length);
   sprs->reply = reply;
@@ -107,21 +109,14 @@ send_peer_ready_run (void *cls,
  */
 struct GNUNET_TESTING_Command
 GNUNET_TESTING_cmd_send_peer_ready (const char *label,
-                                    TESTING_CMD_HELPER_write_cb write_message)
+                                    GNUNET_TESTING_cmd_helper_write_cb write_message)
 {
   struct SendPeerReadyState *sprs;
 
   sprs = GNUNET_new (struct SendPeerReadyState);
   sprs->write_message = write_message;
-  {
-    struct GNUNET_TESTING_Command cmd = {
-      .cls = sprs,
-      .label = label,
-      .run = &send_peer_ready_run,
-      .cleanup = &send_peer_ready_cleanup,
-      .traits = &send_peer_ready_traits
-    };
-
-    return cmd;
-  }
+  return GNUNET_TESTING_command_new (sprs, label,
+                                     &send_peer_ready_run,
+                                     &send_peer_ready_cleanup,
+                                     &send_peer_ready_traits, NULL);
 }
