@@ -25,7 +25,6 @@
  * @author Marcello Stanisci (GNU Taler testing)
  * @author t3sserakt
  */
-#include "gnunet_common.h"
 #include "platform.h"
 #include "gnunet_util_lib.h"
 #include "gnunet_testing_ng_lib.h"
@@ -240,6 +239,81 @@ GNUNET_TESTING_interpreter_lookup_command_all (
 }
 
 
+int
+free_barrier_node_cb (void *cls,
+                      const struct GNUNET_ShortHashCode *key,
+                      void *value)
+{
+  struct FreeBarrierNodeCbCls *free_barrier_node_cb_cls = cls;
+  struct GNUNET_TESTING_NetjailNode *node = value;
+  struct GNUNET_TESTING_Barrier *barrier = free_barrier_node_cb_cls->barrier;
+  struct GNUNET_TESTING_Interpreter *is = free_barrier_node_cb_cls->is;
+
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "free_barrier_node_cb\n");
+  if (GNUNET_NO == is->finishing)
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+                "TST_interpreter_send_barrier_crossable\n");
+    TST_interpreter_send_barrier_crossable (is,
+                                            barrier->name,
+                                            node->node_number);
+  }
+  GNUNET_assert (GNUNET_YES == GNUNET_CONTAINER_multishortmap_remove (
+                   barrier->nodes, key, node));
+  return GNUNET_YES;
+}
+
+
+int
+free_barriers_cb (void *cls,
+                  const struct GNUNET_ShortHashCode *key,
+                  void *value)
+{
+  struct GNUNET_TESTING_Interpreter *is = cls;
+  struct GNUNET_TESTING_Barrier *barrier = value;
+  struct CommandListEntry *pos;
+  struct FreeBarrierNodeCbCls *free_barrier_node_cb_cls;
+
+  if (NULL != barrier->nodes)
+  {
+    free_barrier_node_cb_cls = GNUNET_new (struct FreeBarrierNodeCbCls);
+    free_barrier_node_cb_cls->barrier = barrier;
+    free_barrier_node_cb_cls->is = is;
+    GNUNET_CONTAINER_multishortmap_iterate (barrier->nodes,
+                                            free_barrier_node_cb,
+                                            free_barrier_node_cb_cls);
+    GNUNET_CONTAINER_multishortmap_destroy (barrier->nodes);
+    barrier->nodes = NULL;
+  }
+
+  while (NULL != (pos = barrier->cmds_head))
+  {
+    GNUNET_CONTAINER_DLL_remove (barrier->cmds_head,
+                                 barrier->cmds_tail,
+                                 pos);
+    GNUNET_free (pos);
+  }
+  GNUNET_free (barrier);
+  return GNUNET_YES;
+}
+
+
+/**
+  * Deleting all barriers create in the context of this interpreter.
+  *
+  * @param is The interpreter.
+  */
+static void
+interpreter_delete_barriers (struct GNUNET_TESTING_Interpreter *is)
+{
+  GNUNET_CONTAINER_multishortmap_iterate (is->barriers,
+                                          free_barriers_cb,
+                                          is);
+  GNUNET_CONTAINER_multishortmap_destroy (is->barriers);
+}
+
+
 /**
  * Finish the test run, return the final result.
  *
@@ -286,6 +360,7 @@ finish_test (void *cls)
   GNUNET_free (is->commands);
   is->rc (is->rc_cls,
           is->result);
+  interpreter_delete_barriers (is);
   GNUNET_free (is->helper);
   GNUNET_free (is);
 }
@@ -520,6 +595,7 @@ GNUNET_TESTING_run (const struct GNUNET_TESTING_Command *commands,
   return is;
 }
 
+
 struct GNUNET_TESTING_Command
 GNUNET_TESTING_command_new (void *cls,
                             const char *label,
@@ -543,6 +619,7 @@ GNUNET_TESTING_command_new (void *cls,
 
 }
 
+
 /**
  * Closure for #loop_run().
  */
@@ -603,6 +680,7 @@ loop_run (void *cls)
                       mp);
 }
 
+
 /**
  * Continuation function from GNUNET_HELPER_send()
  *
@@ -617,6 +695,7 @@ clear_msg (void *cls, int result)
   GNUNET_assert (GNUNET_YES == result);
 }
 
+
 /**
  * Adding a helper handle to the interpreter.
  *
@@ -632,7 +711,7 @@ GNUNET_TESTING_add_netjail_helper (struct GNUNET_TESTING_Interpreter *is,
 
 
 /**
- * Send Message to netjail nodes. 
+ * Send Message to netjail nodes.
  *
  * @param is The interpreter.
  * @param global_node_number The netjail node to inform.
@@ -640,8 +719,8 @@ GNUNET_TESTING_add_netjail_helper (struct GNUNET_TESTING_Interpreter *is,
  */
 void
 send_message_to_netjail (struct GNUNET_TESTING_Interpreter *is,
-                                        unsigned int global_node_number,
-                                        struct GNUNET_MessageHeader *header)
+                         unsigned int global_node_number,
+                         struct GNUNET_MessageHeader *header)
 {
   const struct GNUNET_HELPER_Handle *helper;
 
@@ -657,10 +736,11 @@ send_message_to_netjail (struct GNUNET_TESTING_Interpreter *is,
     NULL);
 }
 
+
 void
 TST_interpreter_send_barrier_crossable (struct GNUNET_TESTING_Interpreter *is,
-                                      const char *barrier_name,
-                                      unsigned int global_node_number)
+                                        const char *barrier_name,
+                                        unsigned int global_node_number)
 {
   struct CommandBarrierCrossable *adm;
   size_t msg_length;
@@ -677,38 +757,12 @@ TST_interpreter_send_barrier_crossable (struct GNUNET_TESTING_Interpreter *is,
   adm->header.size = htons ((uint16_t) msg_length);
   memcpy (&adm[1], barrier_name, name_len);
   send_message_to_netjail (is,
-                                          global_node_number,
-                                          &adm->header);
+                           global_node_number,
+                           &adm->header);
   GNUNET_free (adm);
 }
 
 
-
-int
-free_barrier_node_cb (void *cls,
-                      const struct GNUNET_ShortHashCode *key,
-                      void *value)
-{
-  struct FreeBarrierNodeCbCls *free_barrier_node_cb_cls = cls;
-  struct GNUNET_TESTING_NetjailNode *node = value;
-  struct GNUNET_TESTING_Barrier *barrier = free_barrier_node_cb_cls->barrier;
-  struct GNUNET_TESTING_Interpreter *is = free_barrier_node_cb_cls->is;
-
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "free_barrier_node_cb\n");
-  if (GNUNET_NO == is->finishing)
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "TST_interpreter_send_barrier_crossable\n");
-    TST_interpreter_send_barrier_crossable (is,
-                                          barrier->name,
-                                          node->node_number);
-  }
-  GNUNET_assert (GNUNET_YES == GNUNET_CONTAINER_multishortmap_remove (barrier->nodes, key, node));
-  return GNUNET_YES;
-}
-
-
 /**
   * Getting a barrier from the interpreter.
   *
@@ -718,7 +772,7 @@ free_barrier_node_cb (void *cls,
   */
 struct GNUNET_TESTING_Barrier *
 TST_interpreter_get_barrier (struct GNUNET_TESTING_Interpreter *is,
-                            const char *barrier_name)
+                             const char *barrier_name)
 {
   struct GNUNET_HashCode hc;
   struct GNUNET_ShortHashCode create_key;
@@ -745,7 +799,7 @@ TST_interpreter_finish_attached_cmds (struct GNUNET_TESTING_Interpreter *is,
   struct CommandListEntry *pos;
   struct FreeBarrierNodeCbCls *free_barrier_node_cb_cls;
   struct GNUNET_TESTING_Barrier *barrier = TST_interpreter_get_barrier (is,
-                                                                       barrier_name);
+                                                                        barrier_name);
 
   while (NULL != barrier && NULL != (pos = barrier->cmds_head))
   {
@@ -756,8 +810,8 @@ TST_interpreter_finish_attached_cmds (struct GNUNET_TESTING_Interpreter *is,
         GNUNET_NO == pos->command->asynchronous_finish)
     {
       GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                "command label %s finish\n",
-                pos->command->label);
+                  "command label %s finish\n",
+                  pos->command->label);
       GNUNET_TESTING_async_finish (pos->command->ac);
     }
     else if (GNUNET_NO == pos->command->ac->finished)
@@ -781,7 +835,8 @@ TST_interpreter_finish_attached_cmds (struct GNUNET_TESTING_Interpreter *is,
     free_barrier_node_cb_cls->is = is;
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "freeing nodes\n");
-    GNUNET_CONTAINER_multishortmap_iterate (barrier->nodes, free_barrier_node_cb,
+    GNUNET_CONTAINER_multishortmap_iterate (barrier->nodes,
+                                            free_barrier_node_cb,
                                             free_barrier_node_cb_cls);
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "nodes freed\n");
@@ -792,53 +847,6 @@ TST_interpreter_finish_attached_cmds (struct GNUNET_TESTING_Interpreter *is,
 }
 
 
-int
-free_barriers_cb (void *cls,
-                  const struct GNUNET_ShortHashCode *key,
-                  void *value)
-{
-  struct GNUNET_TESTING_Interpreter *is = cls;
-  struct GNUNET_TESTING_Barrier *barrier = value;
-  struct CommandListEntry *pos;
-  struct FreeBarrierNodeCbCls *free_barrier_node_cb_cls;
-
-  if (NULL != barrier->nodes)
-  {
-    free_barrier_node_cb_cls = GNUNET_new (struct FreeBarrierNodeCbCls);
-    free_barrier_node_cb_cls->barrier = barrier;
-    free_barrier_node_cb_cls->is = is;
-    GNUNET_CONTAINER_multishortmap_iterate (barrier->nodes, free_barrier_node_cb,
-                                            free_barrier_node_cb_cls);
-    GNUNET_CONTAINER_multishortmap_destroy (barrier->nodes);
-    barrier->nodes = NULL;
-  }
-
-  while (NULL != (pos = barrier->cmds_head))
-  {
-    GNUNET_CONTAINER_DLL_remove (barrier->cmds_head,
-                                 barrier->cmds_tail,
-                                 pos);
-    GNUNET_free (pos);
-  }
-  GNUNET_free (barrier);
-  return GNUNET_YES;
-}
-
-/**
-  * Deleting all barriers create in the context of this interpreter.
-  *
-  * @param is The interpreter.
-  */
-void
-TST_interpreter_delete_barriers (struct GNUNET_TESTING_Interpreter *is)
-{
-  GNUNET_CONTAINER_multishortmap_iterate (is->barriers,
-                                          free_barriers_cb,
-                                          is);
-  GNUNET_CONTAINER_multishortmap_destroy (is->barriers);
-}
-
-
 /**
  * Add a barrier to the loop.
  *
@@ -847,7 +855,7 @@ TST_interpreter_delete_barriers (struct GNUNET_TESTING_Interpreter *is)
  */
 void
 TST_interpreter_add_barrier (struct GNUNET_TESTING_Interpreter *is,
-                                        struct GNUNET_TESTING_Barrier *barrier)
+                             struct GNUNET_TESTING_Barrier *barrier)
 {
   struct GNUNET_HashCode hc;
   struct GNUNET_ShortHashCode create_key;
