@@ -47,7 +47,7 @@ main (int argc,
   size_t data_len;
 
   GNUNET_log_setup ("test-netjail",
-                    "DEBUG",
+                    "INFO",
                     NULL);
 
   if (0 == strcmp ("-s", argv[1]))
@@ -94,12 +94,12 @@ main (int argc,
     GNUNET_TESTING_cmd_netjail_start ("netjail-start",
                                       topology_data_script,
                                       &read_file),
-    GNUNET_TESTING_cmd_netjail_start_testing_system ("netjail-start-testbed",
+    GNUNET_TESTING_cmd_netjail_start_cmds_helper ("netjail-start-testbed",
                                                      topology,
                                                      &read_file,
                                                      topology_data_script,
                                                      TIMEOUT),
-    GNUNET_TESTING_cmd_stop_testing_system ("stop-testbed",
+    GNUNET_TESTING_cmd_stop_cmds_helper ("stop-testbed",
                                             "netjail-start-testbed",
                                             topology),
     GNUNET_TESTING_cmd_netjail_stop ("netjail-stop",
