@@ -25,8 +25,9 @@
  * @author Christian Grothoff
  */
 
+
 #include "platform.h"
-#include "gnunet_container_lib.h"
+#include "gnunet_util_lib.h"
 
 #define LOG(kind, ...) GNUNET_log_from (kind, "util-container-heap", \
                                         __VA_ARGS__)
