@@ -24,9 +24,10 @@
  * @author Christian Grothoff
  * @author Florian Dold
  */
+
 #include "platform.h"
 #include <gcrypt.h>
-#include "gnunet_crypto_lib.h"
+#include "gnunet_util_lib.h"
 
 
 #define LOG(kind, ...) GNUNET_log_from (kind, "util-crypto-mpi", __VA_ARGS__)
@@ -157,8 +158,8 @@ GNUNET_CRYPTO_mpi_scan_unsigned (gcry_mpi_t *result,
  */
 void
 GNUNET_CRYPTO_mpi_scan_unsigned_le (gcry_mpi_t *result,
-                                 const void *data,
-                                 size_t size)
+                                    const void *data,
+                                    size_t size)
 {
   int rc;
 
